local M = {}
M.type = "auxiliary"
M.relevantDevice = nil

local motors = {}
local powerDisplay = 0
local motorCount = 0
local isMoving = nil
local powerDisplaySmoother = newExponentialSmoothing(30)
local offset = 2400
local torqueMultiplier = 1.55
local regenTorqueMultiplier = 0.8

local function updateGFX()
    powerDisplay = 0
    motorCount = 0
    isMoving = electrics.values.wheelspeed > 0.1

    for _, motor in ipairs(motors) do
        powerDisplay = powerDisplay + (motor.throttle or 0) * torqueMultiplier -- this value is dependant on the gauges
        powerDisplay = powerDisplay - (motor.regenThrottle or 0) * regenTorqueMultiplier -- this value is dependant on the gauges
        motorCount = motorCount + 1
    end

    powerDisplay = (motorCount > 0 and (powerDisplay / motorCount * (isMoving and 1 or 0)) or 0)
    electrics.values.powerDisplay = powerDisplaySmoother:get(powerDisplay * 3000) + offset
end

local function init(jbeamData)
    powerDisplay = 0
    electrics.values.powerDisplay = 0
    motors = powertrain.getDevicesByType("electricMotor")

    offset = jbeamData.offset or 0
    torqueMultiplier = jbeamData.torqueMultiplier or 1
    regenTorqueMultiplier = jbeamData.regenTorqueMultiplier or 1
end

M.reset = init
M.init = init
M.updateGFX = updateGFX

return M